# snr

Snr is the text-based interface for the project "Stick 'n' Run". Please see [snr-meta](https://github.com/GlobularOne/snr-meta) for more information.

## Installation

To install snr, use pip:

```sh
sudo pip3 install snr
```

Or, installation could be from source code. First fetch the source code:

```sh
git clone https://github.com/GlobularOne/snr.git
```

And then install using pip:

```sh
sudo pip3 install .
```

If you get a message about externally managed environment, add the `--break-system-packages` flag.

After installation (from either method), snr needs to be initialized:

```sh
sudo snr --init
```

Snr should be available for use.

## Contacting the author

You can always send an email to me. I am available as `GlobularOne@proton.me`

## License

Apache Software License 2.0. See the [LICENSE](https://github.com/GlobularOne/snr/blob/main/LICENSE) file for more information.
